# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.0.0] 2024-06-26

### Added

### Changed

### Removed


## [0.9.5] 2024-06-24

### Added

### Changed

### Removed


## [0.9.4] 2024-06-24

### Changed

* Fixed missing dependency for GH.

## [0.9.3] 2024-06-24

### Added

* Add GH components to release.


## [0.9.2] 2024-06-24

### Added

### Changed

### Removed


## [0.9.1] 2024-06-24

* Zenodo DOI generation.

## [0.9.0] 2024-06-24

* Initial release.

